@@ -27,13 +27,3 @@ test_that("test ale",{
   expl_glm <- feature_response(explainer_glm, "age", "ale")
   expect_true("feature_response_explainer" %in% class(expl_glm))
 })
-
-test_that("test gender", {
-  expl_glm <- feature_response(explainer_glm, "gender", which_class = 1)
-  expl_glm <- feature_response(explainer_glm, "gender")
-  expl_glm <- feature_response(explainer_glm, "gender", "factor")
-  expect_true("feature_response_explainer" %in% class(expl_glm))
-
-  expl_rf <- feature_response(explainer_rf, "gender", "factor")
-  expect_true("factorMerger_list" %in% class(expl_rf))
-})
